@@ -71,7 +71,11 @@ _DEFAULT_CONFIG = {
 }
 
 # Metadata which may influence execution behavior
-_DEFAULT_CONSTRAINT_VALUES = {
+_DEFAULT_CONSTRAINT_VALUES = {"backend": "local"}
+
+# Going Forward we only want to return the backend field of DEFAULT_CONSTRAINT_VALUES
+# The rest of those parameters will now be in this dictionary
+_DEFAULT_CONSTRAINTS_DEPRECATED = {
     "schedule": False,
     "num_cpu": 1,
     "cpu_feature_set": [],
